summaryrefslogtreecommitdiffstats
path: root/main
diff options
context:
space:
mode:
authorTrashguy <trashguy@gmail.com>2024-10-11 12:21:42 -0400
committerSpartan322 <Megacake1234@gmail.com>2024-10-13 15:05:24 -0400
commit9901f655fb46bd345770ad5f4a1638c4051b1816 (patch)
treebb22b4881145f122568c8f2e51e912078ad1b4fc /main
parent6699ae7897658e44efc3cfb2cba91c11a8f5aa6a (diff)
downloadredot-engine-9901f655fb46bd345770ad5f4a1638c4051b1816.tar.gz
Rebrand Godot 4.3 to Redot
Diffstat (limited to 'main')
-rw-r--r--main/app_icon.pngbin3770 -> 2651 bytes
-rw-r--r--main/main.cpp26
-rw-r--r--main/splash.pngbin14766 -> 7814 bytes
-rw-r--r--main/steam_tracker.h2
4 files changed, 14 insertions, 14 deletions
diff --git a/main/app_icon.png b/main/app_icon.png
index cf31af18a4..b99382dadd 100644
--- a/main/app_icon.png
+++ b/main/app_icon.png
Binary files differ
diff --git a/main/splash.png b/main/splash.png
index 7bddd4325a..fb65059f91 100644
--- a/main/splash.png
+++ b/main/splash.png
Binary files differ
diff --git a/main/steam_tracker.h b/main/steam_tracker.h
index 535b81b950..38d780339e 100644
--- a/main/steam_tracker.h
+++ b/main/steam_tracker.h
@@ -36,7 +36,7 @@
#include "core/os/os.h"
// SteamTracker is used to load SteamAPI dynamic library and initialize
-// the interface, this notifies Steam that Godot editor is running and
+// the interface, this notifies Steam that Redot editor is running and
// allow tracking of the usage time of child instances of the engine
// (e.g., opened projects).
//
diff --git a/main/main.cpp b/main/main.cpp
index dbd9752948..8ef00f8793 100644
--- a/main/main.cpp
+++ b/main/main.cpp
@@ -494,7 +494,7 @@ void Main::print_help_option(const char *p_option, const char *p_description, CL
void Main::print_help(const char *p_binary) {
print_header(true);
print_help_copyright("Free and open source software under the terms of the MIT license.");
- print_help_copyright("(c) 2014-present Godot Engine contributors. (c) 2007-present Juan Linietsky, Ariel Manzur.");
+ print_help_copyright("(c) 2024-present Redot Engine contributors. (c) 2014-present Godot Engine contributors. (c) 2007-present Juan Linietsky, Ariel Manzur.");
print_help_title("Usage");
OS::get_singleton()->print(" %s \u001b[96m[options] [path to scene or \"project.godot\" file]\u001b[0m\n", p_binary);
@@ -641,9 +641,9 @@ void Main::print_help(const char *p_binary) {
#ifndef DISABLE_DEPRECATED
// Commands are long; split the description to a second line.
print_help_option("--convert-3to4 ", "\n", CLI_OPTION_AVAILABILITY_HIDDEN);
- print_help_option(" [max_file_kb] [max_line_size]", "Converts project from Godot 3.x to Godot 4.x.\n", CLI_OPTION_AVAILABILITY_EDITOR);
+ print_help_option(" [max_file_kb] [max_line_size]", "Converts project from Redot 3.x to Redot 4.x.\n", CLI_OPTION_AVAILABILITY_EDITOR);
print_help_option("--validate-conversion-3to4 ", "\n", CLI_OPTION_AVAILABILITY_HIDDEN);
- print_help_option(" [max_file_kb] [max_line_size]", "Shows what elements will be renamed when converting project from Godot 3.x to Godot 4.x.\n", CLI_OPTION_AVAILABILITY_EDITOR);
+ print_help_option(" [max_file_kb] [max_line_size]", "Shows what elements will be renamed when converting project from Redot 3.x to Redot 4.x.\n", CLI_OPTION_AVAILABILITY_EDITOR);
#endif // DISABLE_DEPRECATED
print_help_option("--doctool [path]", "Dump the engine API reference to the given <path> (defaults to current directory) in XML format, merging if existing files are found.\n", CLI_OPTION_AVAILABILITY_EDITOR);
print_help_option("--no-docbase", "Disallow dumping the base types (used with --doctool).\n", CLI_OPTION_AVAILABILITY_EDITOR);
@@ -653,8 +653,8 @@ void Main::print_help(const char *p_binary) {
#endif
print_help_option("--build-solutions", "Build the scripting solutions (e.g. for C# projects). Implies --editor and requires a valid project to edit.\n", CLI_OPTION_AVAILABILITY_EDITOR);
print_help_option("--dump-gdextension-interface", "Generate a GDExtension header file \"gdextension_interface.h\" in the current folder. This file is the base file required to implement a GDExtension.\n", CLI_OPTION_AVAILABILITY_EDITOR);
- print_help_option("--dump-extension-api", "Generate a JSON dump of the Godot API for GDExtension bindings named \"extension_api.json\" in the current folder.\n", CLI_OPTION_AVAILABILITY_EDITOR);
- print_help_option("--dump-extension-api-with-docs", "Generate JSON dump of the Godot API like the previous option, but including documentation.\n", CLI_OPTION_AVAILABILITY_EDITOR);
+ print_help_option("--dump-extension-api", "Generate a JSON dump of the Redot API for GDExtension bindings named \"extension_api.json\" in the current folder.\n", CLI_OPTION_AVAILABILITY_EDITOR);
+ print_help_option("--dump-extension-api-with-docs", "Generate JSON dump of the Redot API like the previous option, but including documentation.\n", CLI_OPTION_AVAILABILITY_EDITOR);
print_help_option("--validate-extension-api <path>", "Validate an extension API file dumped (with one of the two previous options) from a previous version of the engine to ensure API compatibility.\n", CLI_OPTION_AVAILABILITY_EDITOR);
print_help_option("", "If incompatibilities or errors are detected, the exit code will be non-zero.\n");
print_help_option("--benchmark", "Benchmark the run time and print it to console.\n", CLI_OPTION_AVAILABILITY_EDITOR);
@@ -868,8 +868,8 @@ int Main::test_entrypoint(int argc, char *argv[], bool &tests_need_run) {
return status;
#else
ERR_PRINT(
- "`--test` was specified on the command line, but this Godot binary was compiled without support for unit tests. Aborting.\n"
- "To be able to run unit tests, use the `tests=yes` SCons option when compiling Godot.\n");
+ "`--test` was specified on the command line, but this Redot binary was compiled without support for unit tests. Aborting.\n"
+ "To be able to run unit tests, use the `tests=yes` SCons option when compiling Redot.\n");
return EXIT_FAILURE;
#endif
}
@@ -1013,7 +1013,7 @@ Error Main::setup(const char *execpath, int argc, char *argv[], bool p_second_ph
#ifdef MACOS_ENABLED
// Ignore the process serial number argument passed by macOS Gatekeeper.
// Otherwise, Godot would try to open a non-existent project on the first start and abort.
if (arg.begins_with("-psn_")) {
I = N;
continue;
@@ -1461,7 +1461,7 @@ Error Main::setup(const char *execpath, int argc, char *argv[], bool p_second_ph
main_args.push_back(arg);
#ifndef DISABLE_DEPRECATED
} else if (arg == "--export") { // For users used to 3.x syntax.
- OS::get_singleton()->print("The Godot 3 --export option was changed to more explicit --export-release / --export-debug / --export-pack options.\nSee the --help output for details.\n");
+ OS::get_singleton()->print("The Redot 3 --export option was changed to more explicit --export-release / --export-debug / --export-pack options.\nSee the --help output for details.\n");
goto error;
} else if (arg == "--convert-3to4") {
// Actually handling is done in start().
@@ -2944,7 +2944,7 @@ Error Main::setup2(bool p_show_boot_logo) {
DisplayServer::get_singleton()->window_set_flag(DisplayServer::WINDOW_FLAG_ALWAYS_ON_TOP, true);
}
- Color clear = GLOBAL_DEF_BASIC("rendering/environment/defaults/default_clear_color", Color(0.3, 0.3, 0.3));
+ Color clear = GLOBAL_DEF_BASIC("rendering/environment/defaults/default_clear_color", Color(0.128, 0.128, 0.128));
RenderingServer::get_singleton()->set_default_clear_color(clear);
if (p_show_boot_logo) {
@@ -3342,7 +3342,7 @@ int Main::start() {
E->get().ends_with(".res") ||
E->get().ends_with(".tres")) {
// Only consider the positional argument to be a scene path if it ends with
// a file extension associated with Godot scenes. This makes it possible
// for projects to parse command-line arguments for custom CLI arguments
// or other file extensions without trouble. This can be used to implement
// "drag-and-drop onto executable" logic, which can prove helpful
@@ -3429,7 +3429,7 @@ int Main::start() {
// Ensure that doctool is running in the root dir, but only if
// user did not manually specify a path as argument.
if (doc_tool_implicit_cwd) {
- ERR_FAIL_COND_V_MSG(!da->dir_exists("doc"), EXIT_FAILURE, "--doctool must be run from the Godot repository's root folder, or specify a path that points there.");
+ ERR_FAIL_COND_V_MSG(!da->dir_exists("doc"), EXIT_FAILURE, "--doctool must be run from the Redot repository's root folder, or specify a path that points there.");
}
}
@@ -3477,7 +3477,7 @@ int Main::start() {
}
}
// For GDExtension docs, use a path that is compatible with Godot modules.
String index_path = gdextension_docs ? doc_tool_path.path_join("doc_classes") : doc_tool_path.path_join("doc/classes");
// Create the main documentation directory if it doesn't exist
Ref<DirAccess> da = DirAccess::create_for_path(index_path);
@@ -1013,7 +1013,7 @@ Error Main::setup(const char *execpath, int argc, char *argv[], bool p_second_ph
#ifdef MACOS_ENABLED
// Ignore the process serial number argument passed by macOS Gatekeeper.
- // Otherwise, Godot would try to open a non-existent project on the first start and abort.
+ // Otherwise, Redot would try to open a non-existent project on the first start and abort.
if (arg.begins_with("-psn_")) {
I = N;
@@ -3342,7 +3342,7 @@ int Main::start() {
E->get().ends_with(".tres")) {
// Only consider the positional argument to be a scene path if it ends with
- // a file extension associated with Godot scenes. This makes it possible
+ // a file extension associated with Redot scenes. This makes it possible
// for projects to parse command-line arguments for custom CLI arguments
// or other file extensions without trouble. This can be used to implement
@@ -3477,7 +3477,7 @@ int Main::start() {
}
}
- // For GDExtension docs, use a path that is compatible with Godot modules.
+ // For GDExtension docs, use a path that is compatible with Redot modules.
String index_path = gdextension_docs ? doc_tool_path.path_join("doc_classes") : doc_tool_path.path_join("doc/classes");
// Create the main documentation directory if it doesn't exist